@@ -7,7 +7,7 @@ from torch.utils.hooks import RemovableHandle
 
 from .formatting import FormattingOptions, Verbosity
 from .layer_info import LayerInfo
-from .model_statistics import ModelStatistics
+from .model_statistics import CORRECTED_INPUT_SIZE_TYPE, ModelStatistics
 
 # Some modules do the computation themselves using parameters
 # or the parameters of children. Treat these as layers.
@@ -41,7 +41,7 @@ def summary(
             Example input tensor of the model (dtypes inferred from model input).
             - OR -
             Shape of input data as a List/Tuple/torch.Size (dtypes must match model input,
-            default is FloatTensors). NOTE: For scalar parameters, use torch.Size([]).
+            default is FloatTensors).
         branching (bool): Whether to use the branching layout for the printed output.
         depth (int): number of nested layers to traverse (e.g. Sequentials)
         verbose (int):
@@ -83,7 +83,12 @@ def summary(
             x = get_input_tensor(input_size, batch_dim, dtypes, device)
 
     else:
-        raise TypeError
+        raise TypeError(
+            "Input type is not recognized. Please ensure input_data is valid.\n"
+            "For multiple inputs to the network, ensure input_data passed in is "
+            "a sequence of tensors or a list of tuple sizes. If you are having trouble here, "
+            "please submit a GitHub issue."
+        )
 
     args = tuple([t.to(device) if torch.is_tensor(t) else t for t in args])
     kwargs = {k: kwargs[k].to(device) if torch.is_tensor(kwargs[k]) else k for k in kwargs}
@@ -107,7 +112,10 @@ def summary(
 
 
 def get_input_tensor(
-    input_size: INPUT_SIZE_TYPE, batch_dim: int, dtypes: List[torch.dtype], device: torch.device,
+    input_size: CORRECTED_INPUT_SIZE_TYPE,
+    batch_dim: int,
+    dtypes: List[torch.dtype],
+    device: torch.device,
 ) -> List[torch.Tensor]:
     """ Get input_tensor with batch size 2 for use in model.forward() """
     x = []
@@ -118,17 +126,13 @@ def get_input_tensor(
             input_tensor = torch.rand(*size)
             input_tensor = input_tensor.unsqueeze(dim=batch_dim)
             input_tensor = torch.cat([input_tensor] * 2, dim=batch_dim)
-        else:
-            # Case: input_tensor is a scalar
-            input_tensor = torch.ones(batch_dim)
-            input_tensor = torch.cat([input_tensor] * 2, dim=0)
         result = input_tensor.to(device).type(dtype)
         if isinstance(result, torch.Tensor):
             x.append(result)
     return x
 
 
-def get_correct_input_sizes(input_size: INPUT_SIZE_TYPE) -> List[Union[int, Sequence, torch.Size]]:
+def get_correct_input_sizes(input_size: INPUT_SIZE_TYPE) -> CORRECTED_INPUT_SIZE_TYPE:
     """ Convert input_size to the correct form, which is a list of tuples.
     Also handles multiple inputs to the network. """
 
@@ -142,17 +146,14 @@ def get_correct_input_sizes(input_size: INPUT_SIZE_TYPE) -> List[Union[int, Sequ
 
     assert input_size
     assert all(size > 0 for size in flatten(input_size)), "Negative size found in input_data."
-    # For multiple inputs to the network, make sure everything passed in is a list of tuple sizes.
-    # This code is not very robust, so if you are having trouble here, please submit an issue.
-    if isinstance(input_size, tuple) and isinstance(input_size[0], tuple):
-        return list(input_size)
-    if isinstance(input_size, tuple):
-        return [input_size]
+
     if isinstance(input_size, list) and isinstance(input_size[0], int):
         return [tuple(input_size)]
     if isinstance(input_size, list):
         return input_size
-    raise TypeError
+    if isinstance(input_size, tuple) and isinstance(input_size[0], tuple):
+        return list(input_size)
+    return [input_size]
 
 
 def apply_hooks(
